@@ -263,6 +263,7 @@ if [ "x$NOMODULES" = "x" ]; then
       fi
     fi
   done << EOF
+File::Spec	File-Spec	0.82	1	yes	noarch
 ExtUtils::MakeMaker ExtUtils-MakeMaker 6.32 1	yes	noarch
 Net::CIDR	Net-CIDR	0.11	1	yes	noarch
 IsABundle	IO-stringy	2.110	1	yes	noarch
@@ -275,7 +276,6 @@ IsABundle	MailTools	2.02	1	yes	noarch
 IO		IO		1.2301	1	yes	noarch
 Test::Harness	Test-Harness	2.64	1	yes	noarch
 Test::Simple	Test-Simple	0.70	1	no	noarch
-File::Spec	File-Spec	0.82	1	yes	noarch
 File::Temp	File-Temp	0.19	1	yes	noarch
 HTML::Tagset	HTML-Tagset	3.03	1	yes	noarch
 HTML::Parser	HTML-Parser	3.56	1	yes	i386
@@ -298,6 +298,8 @@ Net::IP		Net-IP		1.25	1	yes	noarch
 Sys::Hostname::Long Sys-Hostname-Long 1.4 1	yes	noarch
 Sys::Syslog	Sys-Syslog	0.18	1	yes	noarch
 Digest::MD5	Digest-MD5	2.36	1	yes	noarch
+Digest::SHA1	Digest-SHA1	2.11	1	yes	noarch
+Net::DNS	Net-DNS		0.63	1	yes	noarch
 EOF
 
 else
